pub unsafe fn getrandom_raw(dest: *mut u8, len: usize) -> Result<(), ()>Expand description
A random byte generator suitable for getrandom custom backends.
dest will be filled with len random bytes.
Call this from a __getrandom_v03_custom(), see getrandom crate
documentation.
Safety
dest and len must be a valid destination to write. dest
does not need to contain initialised memory.